@@ -70,7 +70,7 @@ Attention:
 
 		minWords := getFlagPositiveInt(cmd, "mini-common-words")
 
-		files := getFileListFromArgsAndFile(cmd, args, true, "infile-list", true)
+		files := getFileListFromArgsAndFile(cmd, args, true, "infile-list", !config.SkipFileCheck)
 
 		outfh, err := xopen.Wopen(outFile)
 		checkError(err)
