@@ -110,7 +110,8 @@ Tips:
 		}
 		gapLettersBytes := []byte(gapLetters)
 		gcLettersBytes := []byte{'g', 'c', 'G', 'C'}
-		nLettersBytes := []byte{'X', 'x', 'N', 'n'}
+		nLettersBytesNucl := []byte{'N', 'n'}
+		nLettersBytesProt := []byte{'X', 'x'}
 
 		skipFileCheck := getFlagBool(cmd, "skip-file-check")
 		all := getFlagBool(cmd, "all")
@@ -135,7 +136,7 @@ Tips:
 			}
 		}
 
-		files := getFileListFromArgsAndFile(cmd, args, !skipFileCheck, "infile-list", !skipFileCheck)
+		files := getFileListFromArgsAndFile(cmd, args, true, "infile-list", !(skipFileCheck || config.SkipFileCheck))
 
 		style := &stable.TableStyle{
 			Name: "plain",
@@ -244,7 +245,7 @@ Tips:
 							info.lenAvg,
 							info.lenMax)
 						if all {
-							fmt.Fprintf(outfh, "\t%.1f\t%.1f\t%.1f\t%d\t%d\t%d\t%.2f\t%.2f\t%.2f\t%.2f\t%d",
+							fmt.Fprintf(outfh, "\t%.0f\t%.0f\t%.0f\t%d\t%d\t%d\t%.0f\t%.0f\t%.2f\t%.2f\t%d",
 								info.Q1,
 								info.Q2,
 								info.Q3,
@@ -287,7 +288,7 @@ Tips:
 							info.lenAvg,
 							info.lenMax)
 						if all {
-							fmt.Fprintf(outfh, "\t%.1f\t%.1f\t%.1f\t%d\t%d\t%d\t%.2f\t%.2f\t%.2f\t%.2f\t%d",
+							fmt.Fprintf(outfh, "\t%.0f\t%.0f\t%.0f\t%d\t%d\t%d\t%.0f\t%.0f\t%.2f\t%.2f\t%d",
 								info.Q1,
 								info.Q2,
 								info.Q3,
@@ -338,7 +339,7 @@ Tips:
 							info.lenAvg,
 							info.lenMax)
 						if all {
-							fmt.Fprintf(outfh, "\t%.1f\t%.1f\t%.1f\t%d\t%d\t%d\t%.2f\t%.2f\t%.2f\t%.2f\t%d",
+							fmt.Fprintf(outfh, "\t%.0f\t%.0f\t%.0f\t%d\t%d\t%d\t%.0f\t%.0f\t%.2f\t%.2f\t%d",
 								info.Q1,
 								info.Q2,
 								info.Q3,
@@ -422,6 +423,8 @@ Tips:
 				var record *fastx.Record
 				var fastxReader *fastx.Reader
 				var err error
+				checkSeqType := true
+				var isNucleotide bool
 
 				fastxReader, err = fastx.NewReader(alphabet, file, idRegexp)
 				if err != nil {
@@ -460,12 +463,18 @@ Tips:
 						break
 					}
 
-					if seqFormat == "" {
+					if checkSeqType {
+						checkSeqType = false
+
 						if len(record.Seq.Qual) > 0 {
 							seqFormat = "FASTQ"
 						} else {
 							seqFormat = "FASTA"
 						}
+
+						isNucleotide = fastxReader.Alphabet() == seq.DNA ||
+							fastxReader.Alphabet() == seq.DNAredundant ||
+							fastxReader.Alphabet() == seq.RNA || fastxReader.Alphabet() == seq.RNAredundant
 					}
 
 					lensStats.Add(uint64(len(record.Seq.Seq)))
@@ -486,8 +495,12 @@ Tips:
 						}
 
 						gapSum += uint64(byteutil.CountBytes(record.Seq.Seq, gapLettersBytes))
-						gcSum += uint64(byteutil.CountBytes(record.Seq.Seq, gcLettersBytes))
-						nSum += uint64(byteutil.CountBytes(record.Seq.Seq, nLettersBytes))
+						if isNucleotide {
+							gcSum += uint64(byteutil.CountBytes(record.Seq.Seq, gcLettersBytes))
+							nSum += uint64(byteutil.CountBytes(record.Seq.Seq, nLettersBytesNucl))
+						} else {
+							nSum += uint64(byteutil.CountBytes(record.Seq.Seq, nLettersBytesProt))
+						}
 					}
 				}
 
